netapp_ontap.models.node_controller_flash_cache API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_controller_flash_cache`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeControllerFlashCacheSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeControllerFlashCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `capacity GET`

    Size in bytes

    Example: 1024000000000

  `firmware_version GET`

    The firmware_version field of the node_controller_flash_cache.

    Example: NA05

  `hardware_revision GET`

    The hardware_revision field of the node_controller_flash_cache.

    Example: A1

  `model GET`

    The model field of the node_controller_flash_cache.

    Example: X1970A

  `part_number GET`

    The part_number field of the node_controller_flash_cache.

    Example: 119-00207

  `serial_number GET`

    The serial_number field of the node_controller_flash_cache.

    Example: A22P5061550000187

  `slot GET`

    The slot field of the node_controller_flash_cache.

    Example: 6-1

  `state GET`

    The state field of the node_controller_flash_cache.

    Valid choices:

    - ok
    - erasing
    - erased
    - failed
    - removed